@@ -9,7 +9,7 @@ from pathlib import Path
 import requests
 
 from .utils import get_domain
-from .utils.errors import (AuthenticationException,
+from .utils.errors import (AuthenticationException, DomainException,
                            RefreshTokenExpirationException,
                            catch_requests_error, ensure_response_ok)
 
@@ -199,7 +199,11 @@ class Authentication:
         """
         if self.refresh_token is None:
             raise AuthenticationException()
-        data = {"grant_type": "refresh_token", "client_id": self.client, "refresh_token": self.refresh_token}
+        data = {
+            "grant_type": "refresh_token",
+            "client_id": self.client,
+            "refresh_token": self.refresh_token,
+        }
         self._requesting_oauth_token(data=data)
 
     def refresh_if_needed(self):
@@ -262,7 +266,14 @@ class NeedAuthentication:
     Parent class for class which needs authentication. Provide useful methods
     """
 
-    def _authenticate(self, auth_object: Authentication, auth_file: str, scope: str, use_cache: str, cache_dir: str):
+    def _authenticate(
+        self,
+        auth_object: Authentication,
+        auth_file: str,
+        scope: str,
+        use_cache: str,
+        cache_dir: str,
+    ):
         """
         Method to authenticate.
 
