@@ -165,9 +165,11 @@ class Distribution:
             # check if the elg_licence_url exists
             response = requests.get(elg_licence_url)
             if not response.ok:
-                print(not_downloadable)
-                return None
-            print(f"Please, visit the licence of this corpus distribution by clicking: {elg_licence_url}\n")
+                # print(not_downloadable)
+                # return None
+                print(f"This corpus is distributed with the following licence: {self.licence.name}\n")
+            else:
+                print(f"Please, visit the licence of this corpus distribution by clicking: {elg_licence_url}\n")
             accept = input("Do you accept the licence terms: (yes/[no]): ")
             if accept not in ["yes", "Yes", "y", "Y"]:
                 print("You need to accept the licence terms to download this corpus distribution.")
