@@ -9,7 +9,7 @@ from loguru import logger
 
 try:
     import docker
-    from flask import Flask
+    from flask import Flask, g
     from flask import request as flask_request
     from requests_toolbelt import MultipartDecoder
 except:
@@ -18,8 +18,9 @@ except:
     )
 
 
-from .model import (AudioRequest, Failure, Progress, Request, ResponseObject,
-                    StandardMessages, StructuredTextRequest, TextRequest)
+from .model import (AudioRequest, Failure, ImageRequest, Progress, Request,
+                    ResponseObject, StandardMessages, StructuredTextRequest,
+                    TextRequest)
 from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK, ENV_FLASK
 from .utils.json_encoder import json_encoder
 
@@ -32,12 +33,15 @@ class FlaskService:
 
     requirements = ["gunicorn", "elg[flask]"]
 
-    def __init__(self, name: str):
+    def __init__(self, name: str = "My ELG Service", path: str = "/process"):
         """
         Init function of the FlaskService
 
         Args:
-            name (str): Name of the service. It doesn't have any importance.
+            name (str, optional): Name of the service. It doesn't have any importance.
+            path (str, optional): Path of the endpoint to expose. It can contain parameters, e.g., "/translate/<src>/<target>"
+                later accessible in the process_* methods using the `self.url_param` method, e.g.,
+                self.url_param('src'). Default to "/process".
         """
         self.name = name
         self.app = Flask(name)
@@ -46,7 +50,7 @@ class FlaskService:
         # Don't sort properties alphabetically in response JSON
         self.app.config["JSON_SORT_KEYS"] = False
         self.app.json_encoder = json_encoder(self)
-        self.app.add_url_rule("/process", "process", self.process, methods=["POST"])
+        self.app.add_url_rule(path, "process", self.process, methods=["POST"])
 
     def to_json(self, obj):
         """Hook that can be overridden by subclasses to customise JSON encoding.
@@ -87,11 +91,18 @@ class FlaskService:
         """
         self.app.run()
 
-    def process(self):
+    def url_param(self, name: str):
+        """
+        Method to get give access to url parameters
+        """
+        return g._elg_args[name]
+
+    def process(self, **kwargs):
         """
         Main request processing logic - accepts a JSON request and returns a JSON response.
         """
         logger.info("Process request")
+        g._elg_args = kwargs
         even_stream = True if "text/event-stream" in flask_request.accept_mimetypes else False
         logger.debug("Accept MimeTypes: {mimetypes}", mimetypes=flask_request.accept_mimetypes)
         logger.debug("Accept even-stream: {even_stream}", even_stream=even_stream)
@@ -105,7 +116,7 @@ class FlaskService:
                 if "application/json" in headers["Content-Type"]:
                     for k, v in json.loads(part.content.decode()).items():
                         data[k] = v
-                elif "audio" in headers["Content-Type"]:
+                elif "audio" in headers["Content-Type"] or "image" in headers["Content-Type"]:
                     data["content"] = part.content
                 else:
                     raise ValueError("Unknown Content-Type in multipart request")
@@ -114,10 +125,12 @@ class FlaskService:
 
         request_type = data.get("type")
         logger.debug("Data type: {request_type}", request_type=request_type)
-        if request_type in ["audio", "text", "structuredText"]:
+        if request_type in ["audio", "image", "text", "structuredText"]:
             try:
                 if request_type == "audio":
                     request = AudioRequest(**data)
+                elif request_type == "image":
+                    request = ImageRequest(**data)
                 elif request_type == "text":
                     request = TextRequest(**data)
                 else:
@@ -181,6 +194,9 @@ class FlaskService:
         elif request.type == "structuredText":
             logger.debug("Process structuredText request")
             return self.process_structured_text(request)
+        elif request.type == "image":
+            logger.debug("Process image request")
+            return self.process_image(request)
         elif request.type == "audio":
             logger.debug("Process audio request")
             return self.process_audio(request)
@@ -213,6 +229,15 @@ class FlaskService:
         """
         raise NotImplementedError()
 
+    def process_image(self, request: ImageRequest):
+        """
+        Method to implement if the service takes image as input.
+
+        Args:
+            request (ImageRequest): ImageRequest object.
+        """
+        raise NotImplementedError()
+
     def generator_mapping(self, generator):
         end = False
         try:
@@ -284,7 +309,7 @@ class FlaskService:
         required_files: List[str] = [],
         required_folders: List[str] = [],
         commands: List[str] = [],
-        base_image: str = "python:slim",
+        base_image: str = "python:3.8-slim",
         path: str = None,
         log_level: str = "INFO",
         workers: int = 1,
@@ -297,7 +322,7 @@ class FlaskService:
             required_files (List[str], optional): List of files needed for the service. Defaults to [].
             required_folders (List[str], optional): List of folders needed for the service. Defaults to [].
             commands (List[str], optional): List off additional commands to run in the Dockerfile. Defaults to [].
-            base_image (str, optional): Name of the base Docker image used in the Dockerfile. Defaults to 'python:slim'.
+            base_image (str, optional): Name of the base Docker image used in the Dockerfile. Defaults to 'python:3.8-slim'.
             path (str, optional): Path where to generate the file. Defaults to None.
             log_level (str, optional): The minimum severity level from which logged messages should be displayed. Defaults to 'INFO'.
             workers (int, optional): Number of Gunicorn workers. Defaults to 1.
@@ -327,7 +352,10 @@ class FlaskService:
                     required_folders=required_folders,
                     commands="\n".join(commands),
                     env=ENV_FLASK.format(
-                        workers=workers, timeout=timeout, worker_class=worker_class, log_level=log_level
+                        workers=workers,
+                        timeout=timeout,
+                        worker_class=worker_class,
+                        log_level=log_level,
                     ),
                 )
             )
