@@ -1,6 +1,7 @@
 from .base import (Annotation, Failure, Progress, Request, ResponseObject,
                    StandardMessages, StatusMessage)
-from .request import AudioRequest, StructuredTextRequest, TextRequest
+from .request import (AudioRequest, ImageRequest, StructuredTextRequest,
+                      TextRequest)
 from .response import (AnnotationsResponse, AudioResponse, ClassesResponse,
                        ClassificationResponse, TextsResponse,
                        TextsResponseObject, get_response)
