@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from pydantic import BaseModel, root_validator
 
@@ -27,8 +27,8 @@ class Text(BaseModel):
     annotations: Dict[str, List[Annotation]] = None
     """*(optional)* optional annotations on request"""
 
-    texts: List = None
-    """*(optional)* recursive, same structure (should be List[Text] but postponed annotations introduced post python 3.6)"""
+    texts: "List[Text]" = None
+    """*(optional)* recursive, same structure"""
 
     class Config:
         alias_generator = to_camel
@@ -47,6 +47,22 @@ class Text(BaseModel):
             values["mimeType"] = None
         return values
 
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value: Any = None):
+        if hasattr(self, key):
+            return getattr(self, key)
+        return value
+
+
+Text.update_forward_refs()
+
 
 class StructuredTextRequest(Request):
     """
