@@ -1,4 +1,4 @@
-from typing import List
+from typing import Any, List
 
 from pydantic import BaseModel, Field
 
@@ -21,6 +21,19 @@ class ClassesResponse(BaseModel):
     class Config:
         alias_generator = to_camel
 
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value: Any = None):
+        if hasattr(self, key):
+            return getattr(self, key)
+        return value
+
 
 class ClassificationResponse(ResponseObject):
     """
