@@ -1,5 +1,5 @@
 from numbers import Number
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from pydantic import BaseModel, root_validator
 
@@ -18,7 +18,7 @@ class TextsResponseObject(BaseModel):
     content: str = None
     """*(optional)* string of translated/transcribed text"""
 
-    texts: List = None
+    texts: "List[TextsResponseObject]" = None
     """*(optional)* list of same structures, recursive"""
 
     score: Number = None
@@ -50,6 +50,19 @@ class TextsResponseObject(BaseModel):
             raise ValueError("A branch node should not have a score attached")
         return values
 
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value: Any = None):
+        if hasattr(self, key):
+            return getattr(self, key)
+        return value
+
     def auto_content(self):
         if self.features is not None and self.annotations is not None:
             return self.dict()
@@ -66,6 +79,9 @@ class TextsResponseObject(BaseModel):
             return self.texts
 
 
+TextsResponseObject.update_forward_refs()
+
+
 class TextsResponse(ResponseObject):
     """
     Response consisting of a set of one or more new texts, each with optional annotations attached to it.
