@@ -9,7 +9,7 @@ from loguru import logger
 
 try:
     import docker
-    from quart import Quart, current_app, make_response
+    from quart import Quart, current_app, g, make_response
     from quart import request as input_request
     from requests_toolbelt import MultipartDecoder
     from werkzeug.exceptions import BadRequest, RequestEntityTooLarge
@@ -21,8 +21,9 @@ except:
         "Extra dependencies need to be install to use the QuartService class. Please run: `pip install elg[quart]`."
     )
 
-from .model import (AudioRequest, Failure, Progress, ResponseObject,
-                    StandardMessages, StructuredTextRequest, TextRequest)
+from .model import (AudioRequest, Failure, ImageRequest, Progress,
+                    ResponseObject, StandardMessages, StructuredTextRequest,
+                    TextRequest)
 from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_QUART, ENV_QUART
 from .utils.json_encoder import json_encoder
 
@@ -34,7 +35,10 @@ class ProcessingError(Exception):
 
     @staticmethod
     def InternalError(text, detail={}):
-        return ProcessingError(500, StandardMessages.generate_elg_service_internalerror(params=[text], detail=detail))
+        return ProcessingError(
+            500,
+            StandardMessages.generate_elg_service_internalerror(params=[text], detail=detail),
+        )
 
     @staticmethod
     def InvalidRequest(detail={}):
@@ -134,12 +138,20 @@ class QuartService:
     requirements = ["elg[quart]"]
     consume_generator = True
 
-    def __init__(self, name: str, request_size_limit: int = None):
+    def __init__(
+        self,
+        name: str = "My ELG Service",
+        path: str = "/process",
+        request_size_limit: int = None,
+    ):
         """
         Init function of the QuartService
 
         Args:
-            name (str): Name of the service. It doesn't have any importance.
+            name (str, optional): Name of the service. It doesn't have any importance.
+            path (str, optional): Path of the endpoint to expose. It can contain parameters, e.g., "/translate/<src>/<target>"
+                later accessible in the process_* methods using the `self.url_param` method, e.g.,
+                self.url_param('src'). Default to "/process".
         """
         self.name = name
         self.app = Quart(name)
@@ -164,7 +176,7 @@ class QuartService:
         self.app.after_serving(self.shutdown)
 
         self.app.add_url_rule("/health", "health", self.health, methods=["GET"])
-        self.app.add_url_rule("/process", "process", self.process, methods=["POST"])
+        self.app.add_url_rule(path, "process", self.process, methods=["POST"])
 
     def to_json(self, obj):
         """Hook that can be overridden by subclasses to customise JSON encoding.
@@ -243,6 +255,10 @@ class QuartService:
     async def parse_plain(audioformat):
         return {"type": "audio", "format": audioformat}, input_request.body
 
+    @staticmethod
+    async def parse_plain_image(image_format):
+        return {"type": "image", "format": image_format}, input_request.body
+
     @staticmethod
     async def parse_multipart():
         boundary = input_request.mimetype_params.get("boundary", "").encode("ascii")
@@ -253,9 +269,9 @@ class QuartService:
             """
             Logic: the request should consist of first a "form field" part named
             "request" containing JSON, and second a "file upload" part named
-            "content" containing the audio.  This generator fully parses the JSON
+            "content" containing the audio or image. This generator fully parses the JSON
             part and yields that as a dict, then subsequently yields chunks of the
-            audio data until they run out.  We create the generator and consume its
+            audio/image data until they run out.  We create the generator and consume its
             first yield (the parsed JSON), then return the active generator so the
             rest of the binary chunks can be consumed by the caller in an async for.
             This logic is heavily inspired by quart.formparser but we don't use that
@@ -312,11 +328,18 @@ class QuartService:
         # chunks of bytes
         return (await mp_gen.asend(None)), mp_gen
 
-    async def process(self):
+    def url_param(self, name: str):
+        """
+        Method to get give access to url parameters
+        """
+        return g._elg_args[name]
+
+    async def process(self, **kwargs):
         """
         Main request processing logic - accepts a JSON request and returns a JSON response.
         """
         logger.info("Process request")
+        g._elg_args = kwargs
         even_stream = True if "text/event-stream" in input_request.accept_mimetypes else False
         logger.debug("Accept MimeTypes: {mimetypes}", mimetypes=input_request.accept_mimetypes)
         logger.debug("Accept even-stream: {even_stream}", even_stream=even_stream)
@@ -332,6 +355,10 @@ class QuartService:
         elif input_request.mimetype == "audio/wav" or input_request.mimetype == "audio/x-wav":
             data, content = await self.parse_plain("LINEAR16")
             data["content"] = content
+        elif input_request.mimetype.startswith("image/"):
+            mime_type = input_request.mimetype.split("/")[1]
+            data, content = await self.parse_plain_image(mime_type)
+            data["content"] = content
         elif input_request.mimetype == "application/json":
             data = await input_request.get_json()
         else:
@@ -343,6 +370,12 @@ class QuartService:
                 request = AudioRequest(**data)
             except Exception as e:
                 raise ProcessingError.InvalidRequest()
+        elif data.get("type") == "image":
+            try:
+                logger.info(data)
+                request = ImageRequest(**data)
+            except Exception as e:
+                raise ProcessingError.InvalidRequest()
         elif data.get("type") == "text":
             try:
                 request = TextRequest(**data)
@@ -422,6 +455,9 @@ class QuartService:
         if request.type == "audio":
             logger.debug("Process audio request")
             return await self.process_audio(request)
+        if request.type == "image":
+            logger.debug("Process image request")
+            return await self.process_image(request)
         raise ProcessingError.InvalidRequest()
 
     async def process_text(self, request: TextRequest):
@@ -451,6 +487,15 @@ class QuartService:
         """
         raise ProcessingError.UnsupportedType()
 
+    async def process_image(self, request: ImageRequest):
+        """
+        Method to implement if the service takes an image as input. This method must be implemented as async.
+
+        Args:
+            request (ImageRequest): ImageRequest object.
+        """
+        raise ProcessingError.UnsupportedType()
+
     async def generator_mapping(self, generator):
         end = False
         try:
@@ -522,7 +567,7 @@ class QuartService:
         required_files: List[str] = [],
         required_folders: List[str] = [],
         commands: List[str] = [],
-        base_image: str = "python:slim",
+        base_image: str = "python:3.8-slim",
         path: str = None,
         log_level: str = "INFO",
     ):
@@ -532,7 +577,7 @@ class QuartService:
             required_files (List[str], optional): List of files needed for the service. Defaults to [].
             required_folders (List[str], optional): List of folders needed for the service. Defaults to [].
             commands (List[str], optional): List off additional commands to run in the Dockerfile. Defaults to [].
-            base_image (str, optional): Name of the base Docker image used in the Dockerfile. Defaults to 'python:slim'.
+            base_image (str, optional): Name of the base Docker image used in the Dockerfile. Defaults to 'python:3.8-slim'.
             path (str, optional): Path where to generate the file. Defaults to None.
             log_level (str, optional): The minimum severity level from which logged messages should be displayed. Defaults to 'INFO'.
         """
