@@ -17,8 +17,8 @@ import requests
 from .authentication import (ONE_HUNDRED_YEARS_IN_SECONDS, Authentication,
                              NeedAuthentication, need_authentication)
 from .entity import Entity, MetadataRecordObj
-from .model import (AudioRequest, Request, StructuredTextRequest, TextRequest,
-                    get_response)
+from .model import (AudioRequest, ImageRequest, Request, StructuredTextRequest,
+                    TextRequest, get_response)
 from .utils import (MIME, get_argument_from_json, get_domain, get_information,
                     get_metadatarecord, map_metadatarecord_to_result)
 from .utils.errors import (DomainException, NotElgServiceException,
@@ -324,6 +324,7 @@ class Service(Entity, NeedAuthentication):
                 "elg_execution_location": f"{local_domain}/async/process/{name}",
             }
         }
+
         parameters = {
             "id": 0,
             "resource_name": name,
@@ -412,6 +413,10 @@ class Service(Entity, NeedAuthentication):
                     request = AudioRequest.from_file(request_input)
                 elif request_type == "audioStream":
                     request = AudioRequest.from_file(request_input, streaming=True)
+                elif request_type == "image":
+                    request = ImageRequest.from_file(request_input)
+                elif request_type == "imageStream":
+                    request = ImageRequest.from_file(request_input, streaming=True)
                 else:
                     raise ValueError(
                         "Invalid value for request_type. It musts be 'text', 'structuredText', 'audio', or 'audioStream'."
@@ -447,9 +452,8 @@ class Service(Entity, NeedAuthentication):
 
         headers = {"Authorization": f"Bearer {self.authentication.access_token}"}
         post_kwargs = {}
-        if (
-            isinstance(request, AudioRequest) and self.id == 0
-        ):  # self.id == 0 corresponds to a service initialized from a docker image
+        # self.id == 0 corresponds to a service initialized from a docker image
+        if isinstance(request, AudioRequest) and self.id == 0:
             files = {
                 "request": (
                     None,
@@ -476,6 +480,10 @@ class Service(Entity, NeedAuthentication):
             data = request.content if request.content else request.generator
             post_kwargs["params"] = request.params
             headers["Content-Type"] = "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"
+        elif isinstance(request, ImageRequest):
+            data = request.content if request.content else request.generator
+            post_kwargs["params"] = request.params
+            headers["Content-Type"] = "image/" + request.format
         elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
             data = json.dumps(request.dict())
             headers["Content-Type"] = "application/json"
